@@ -123,7 +123,7 @@ def repairNotes(resNo,chain,missing):
     None:    it writes to a text file
     """
     with open('log.txt', 'a') as log:
-        log.write('The residue No {} in chain {} have '
+        log.write('The residue No {} in chain {} has '
                   'missing atom(s) {}. We have fixed it'
                   .format(resNo, chain,missing)+'\n\n')
 
@@ -214,8 +214,10 @@ def invalid_pdb_file():
     """
     with open('invalid_pdb_file.txt', 'w') as f:
         f.write('Error occured while reading the PDB file'+'\n')
-        f.write('Visit www.protein-science.com and click How-tos'
-               ' to see what PRAS expects'+'\n')
+        f.write('For a .pdb format, ensure that each chain ends'
+               ' with TER and the last chain TER+END.'+'\n')
+        f.write('Also, visit www.protein-science.com and'
+               ' click "How-tos" for more information')
 
         sys.exit(1)
 
@@ -280,11 +282,11 @@ def checkpdbAtoms (pdb_pras, rotamer, mutation, pdb_faspr, keep_ligand, chain_no
                 ' S.G. Lee, K. Hyun. Protein Repair and Analysis Server: A Web' +'\n'+
                 'Server to Repair PDB Structures, Add Missing Heavy'
                 ' Atoms and Hydrogen Atoms, and Assign Secondary Structures by'
-                ' Amide Interactions. J. Chem. Inf. Model., 2022.'+'\n')
+                ' Amide Interactions. J. Chem. Inf. Model., 2022, 62, 4232–4246.'+'\n')
 
         log.write('#'*183+'\n')
 
-        log.write('PRAS 1.0.8. This is a PRAS-generated log file.'
+        log.write('PRAS 1.0.9. This is a PRAS-generated log file.'
                 ' For your information, all missing or fixed atoms'
                 ' and other relevant information concerning the repair'
                 ' are appended below '+'\n')
@@ -337,7 +339,7 @@ def checkpdbAtoms (pdb_pras, rotamer, mutation, pdb_faspr, keep_ligand, chain_no
     except:
         chains = []
 
-    if not chains:
+    if not chains or not chains[0]:
         invalid_pdb_file()
 
     """
