@@ -259,7 +259,7 @@ def assignStructure(filename):
 		with open ('sec_strc_table_'+'chain'+str(n+1)+'.txt', 'w') as f:
 			f.write('When using files generated by this program in a publication, please cite this program as "O.S. Nnyigide, T.O. Nnyigide,'
 				' S.G. Lee, K. Hyun. Protein Repair and Analysis Server: A Web' +'\n'+'Server to Repair PDB Structures, Add Missing Heavy'
-				' Atoms and Hydrogen Atoms, and Assign Secondary Structures by Amide Interactions. J. Chem. Inf. Model., 2022.'+'\n')
+				' Atoms and Hydrogen Atoms, and Assign Secondary Structures by Amide Interactions. J. Chem. Inf. Model., 2022, 62, 4232–4246.'+'\n')
 			f.write('#'*183 +'\n');f.write('Secondary Structure Assignment by Amide-Amide Interactions of the Backbone.'
 			' This is the summary of the measurements used to assign the secondary structure elements' +'\n');f.write('#'*183+'\n')
 			f.write('Residues in PDB \t\t' 'Amide_dihedral\t' 'Phi_dihedral\t' 'Psi_dihedral\t' 'O(i)->N(i+4)\t' 'O(i)->N(i+3)\t'\
