@@ -1,5 +1,5 @@
 import sys
-if len(sys.argv) == 5:
+if len(sys.argv) == 7:
 	import time
 	from Pras_Server.PRAS import repairPDB
 	from Pras_Server.FixHeavyAtoms import fixheavyAtoms
@@ -7,7 +7,7 @@ if len(sys.argv) == 5:
 	from Pras_Server.SecondaryStructure import assignStructure
 	startTime = time.time()
 	
-	fixheavyAtoms(sys.argv[1],sys.argv[2],sys.argv[3],sys.argv[4])
+	fixheavyAtoms(sys.argv[1],sys.argv[2],sys.argv[3],sys.argv[4], sys.argv[5], sys.argv[6])
 
 	#assignStructure('out_no_h.pdb')
 
@@ -16,6 +16,6 @@ if len(sys.argv) == 5:
 	print ('The program took {0} second !'.format(time.time() - startTime))
 
 else:
-	print("PRAS takes 4 compulsory arguments. Execute the code below on your shell prompt to learn more\n")
+	print("PRAS takes 6 compulsory arguments. Execute the code below on your shell prompt to learn more\n")
 
 	print("printf \"from Pras_Server.PRAS import repairPDB\\nprint(repairPDB.__doc__)\\n\\n()\" | python3\n")
\ No newline at end of file
